==> valentina_0.7.52~dfsg.orig.tar.xz: valentina-v0.7.52/src/libs/vpropertyexplorer/vabstractpropertyfactory.h <==
/************************************************************************
 **
 **  @file   vabstractpropertyfactory.h
 **  @author hedgeware <internal(at)hedgeware.net>
 **  @date
 **
 **  @brief
 **  @copyright
 **  All rights reserved. This program and the accompanying materials
 **  are made available under the terms of the GNU Lesser General Public License
 **  (LGPL) version 2.1 which accompanies this distribution, and is available at
 **  http://www.gnu.org/licenses/lgpl-2.1.html
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 **  Lesser General Public License for more details.
 **
 *************************************************************************/

#ifndef VABSTRACTPROPERTYFACTORY_H
#define VABSTRACTPROPERTYFACTORY_H

#include "vpropertyexplorer_global.h"
#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
#include "../vmisc/diagnostic.h"
#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
#include <QObject>

namespace VPE
{

class VProperty;

QT_WARNING_PUSH
QT_WARNING_DISABLE_CLANG("-Wweak-vtables")

class VPROPERTYEXPLORERSHARED_EXPORT VAbstractPropertyFactory
{
public:
    //! Empty virtual destructor
    virtual ~VAbstractPropertyFactory() {}

    //! Creates a new property of a certain type and assigns a name and description (otionally)
    //! \param type The type of the property as string
    //! \param name The property's name
    //! \return Returns the created property or NULL if it couldn't be be created
    virtual VProperty* createProperty(const QString& type, const QString &name) = 0;
};

QT_WARNING_POP

}

#endif // VABSTRACTPROPERTYFACTORY_H

==> valentina_1.0.0~dfsg.orig.tar.xz: valentina-v1.0.0/src/libs/vpropertyexplorer/vabstractpropertyfactory.h <==
/************************************************************************
 **
 **  @file   vabstractpropertyfactory.h
 **  @author hedgeware <internal(at)hedgeware.net>
 **  @date
 **
 **  @brief
 **  @copyright
 **  All rights reserved. This program and the accompanying materials
 **  are made available under the terms of the GNU Lesser General Public License
 **  (LGPL) version 2.1 which accompanies this distribution, and is available at
 **  http://www.gnu.org/licenses/lgpl-2.1.html
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 **  Lesser General Public License for more details.
 **
 *************************************************************************/

#ifndef VABSTRACTPROPERTYFACTORY_H
#define VABSTRACTPROPERTYFACTORY_H

#include "vpropertyexplorer_global.h"
#include <QObject>

namespace VPE
{

class VProperty;

QT_WARNING_PUSH
QT_WARNING_DISABLE_CLANG("-Wweak-vtables")

class VPROPERTYEXPLORERSHARED_EXPORT VAbstractPropertyFactory
{
public:
    VAbstractPropertyFactory() = default;

    //! Empty virtual destructor
    virtual ~VAbstractPropertyFactory() = default;

    VAbstractPropertyFactory(const VAbstractPropertyFactory &) = default;
    auto operator=(const VAbstractPropertyFactory &) -> VAbstractPropertyFactory & = default;

    VAbstractPropertyFactory(VAbstractPropertyFactory &&) = default;
    auto operator=(VAbstractPropertyFactory &&) -> VAbstractPropertyFactory & = default;

    //! Creates a new property of a certain type and assigns a name and description (otionally)
    //! \param type The type of the property as string
    //! \param name The property's name
    //! \return Returns the created property or NULL if it couldn't be be created
    virtual auto createProperty(const QString &type, const QString &name) -> VProperty * = 0;
};

QT_WARNING_POP

} // namespace VPE

#endif // VABSTRACTPROPERTYFACTORY_H
